@@ -112,12 +112,14 @@ f.all <- function(z){
     
 stopifnot(max(Mod(f.all(z))) < 1e-10)
 
+
+
+# Below, jjR means value obtained from R via the package, and jjM means the value given by maple.
+
 # Following test fails sometimes.  It passes on my mac, fails on the linuxbox:
-if(FALSE){
 jjR <- genhypergeo_contfrac_single(U=0.2 , L=c(9.9,2.7,8.7) , z=1+10i)
 jjM <- 1.0007289707983569879 + 0.86250714217251837317e-2i
 stopifnot(Mod(jjR-jjM)<1e-10)
-}
 
 # Test hypergeo_cover1():
 jjR <- hypergeo(pi,pi/2,3*pi/2-4, z=0.1+0.2i)  # ie negative m;  ie f15.3.12()
@@ -132,8 +134,6 @@ jjR <- hypergeo(pi,pi/2,3*pi/2, z=0.1+0.2i)  # m=0 (ie 15.3.10)
 jjM <- 1.0654685003741342889 +0.24452141417139649656i
 stopifnot(Mod(jjR-jjM)<1e-10)
 
-
-
 jjR <- hypergeo(pi,pi/2,3*pi/2+4, z=10.1+0.2i)  # This is positive m (15.3.11)
 jjM <- -0.29639970263878733845 - 0.34765230143995441172i
 stopifnot(Mod(jjR-jjM)<1e-10)
@@ -153,8 +153,6 @@ jjR <- hypergeo(pi,pi+2, 1.1 , 1+10i)
 stopifnot(Mod(jjR-jjM)<1e-10)
 
 
-
-
 # Test hypergeo_cover3()
 jjM <- -0.24397135980533720308e-1 + 0.28819643319432922231i
 jjR <- hypergeo(pi, 1.4, pi+4,1+6i)
@@ -164,8 +162,6 @@ jjM <- -0.10592465301475818414e-1 - 0.15993048891187879153e-1i
 jjR <- hypergeo(pi , pi+1 , pi + 3 , 1+6i)
 stopifnot(Mod(jjR-jjM)<1e-10)
 
-
-
 # Test for hypergeo_taylor():
 jjR <- hypergeo(pi,-4,2.2,1+5i)
 jjM <- 1670.8287595795885335 - 204.81995157365381258i
@@ -177,3 +173,37 @@ stopifnot(Mod(jjR-jjM)<1e-10)
 options(warn=2)
 ignore <- hypergeo(1,2,3,0)
 ignore <- hypergeo(1,1.64,2.64,-0.1111)
+
+
+# another test for a bug reported by John Ormerod, following my
+# ill-considered change from gamma(x)*gamma(y)/gamma(z) to
+# exp(lgamma(x)+lgamma(y)-lgamma(z)).  Now using the much superior
+# .f3() and .f4() notation.
+
+## MMA> N[Hypergeometric2F1[525/100,1,65/10,501/1000],30]
+## Out[6]= 1.70239432012007391092082702795
+
+
+jjR <- hypergeo(5.25,1,6.5,0.501)
+jj_Mathematica <- 1.70239432012007391092082702795
+stopifnot(Mod(jjR-jj_Mathematica) < 1e-10)
+
+
+
+
+
+
+ ## another test for a typo I corrected:
+
+
+ A <- 1
+ B <- 3
+ m <- 2
+jj_R1 <- hypergeo(A,B,A+B+m,0.9+0.01i)
+jj_R2 <- f15.3.11(A,B,m,0.9+0.01i)
+
+mma_string <- 'N[Hypergeometric2F1[1,3,1+3+2,9/10+I/100],30]'
+jj_mathematica <- 2.04925816767572859287575551415 + 0.03163091033158608113987207436i
+stopifnot(abs(jj_R1-jj_mathematica) < 1e-10)
+stopifnot(abs(jj_R2-jj_mathematica) < 1e-10)
+
